# Tafel

A command-line tool for extracting Tafel slopes from MPT files.

This tool is currently in an experimental stage.

## Installation

```
pip install tafel
```




## For developers

### Getting started

```
pdm install
```

### Check code quality

```
pdm run check
```
